@@ -10,7 +10,7 @@ def inference(img_path, lang):
     try:
         macadd=gma()
         '''uniqueadd =["60:e3:2b:34:66:ce"]'''
-        uniqueadd=["c0:25:a5:5c:a5:61"]
+        uniqueadd=["a8:7e:ea:41:ad:34"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
             ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=True)
